@@ -21,6 +21,9 @@
 #endif
 
 #undef free_2
+#undef malloc_2
+#undef realloc_2
+#undef calloc_2
 
 #ifdef _WAVE_HAVE_JUDY
 void free_outstanding(void)
@@ -95,7 +98,11 @@ system("date");
  * wrapped malloc family...
  */
 #ifdef _WAVE_HAVE_JUDY
-void *malloc_2(size_t size)
+void *malloc_2(size_t size
+#ifdef DEBUG_MALLOC_LINES
+, char *filename, int lineno
+#endif
+)
 {
 void *ret;
 
@@ -112,12 +119,20 @@ if(ret)
         }   
         else
         {
-        fprintf(stderr, "FATAL ERROR : Out of memory, sorry.\n");
+#ifdef DEBUG_MALLOC_LINES
+        fprintf(stderr, "FATAL ERROR: malloc_2() Out of memory, sorry. ['%s', %d]\n", filename, lineno);
+#else
+        fprintf(stderr, "FATAL ERROR : malloc_2() Out of memory, sorry.\n");
+#endif
         exit(1);
         }
 }
 #else
-void *malloc_2(size_t size)
+void *malloc_2(size_t size
+#ifdef DEBUG_MALLOC_LINES
+, char *filename, int lineno
+#endif
+)
 {
 void *ret;
 
@@ -139,14 +154,22 @@ if(ret)
 	}
 	else
 	{
-	fprintf(stderr, "FATAL ERROR : Out of memory, sorry.\n");
+#ifdef DEBUG_MALLOC_LINES
+        fprintf(stderr, "FATAL ERROR: malloc_2() Out of memory, sorry. ['%s', %d]\n", filename, lineno);
+#else
+	fprintf(stderr, "FATAL ERROR : malloc_2() Out of memory, sorry.\n");
+#endif
 	exit(1);
 	}
 }
 #endif
 
 #ifdef _WAVE_HAVE_JUDY
-void *realloc_2(void *ptr, size_t size)
+void *realloc_2(void *ptr, size_t size
+#ifdef DEBUG_MALLOC_LINES
+, char *filename, int lineno
+#endif
+)
 {
 void *ret=realloc(ptr, size);
 
@@ -163,12 +186,20 @@ if(ret)
         }
         else
         {
-        fprintf(stderr, "FATAL ERROR : Out of memory, sorry.\n");
+#ifdef DEBUG_MALLOC_LINES
+        fprintf(stderr, "FATAL ERROR: realloc_2() Out of memory, sorry. ['%s', %d]\n", filename, lineno);
+#else
+        fprintf(stderr, "FATAL ERROR : realloc_2() Out of memory, sorry.\n");
+#endif
         exit(1);
         }
 }
 #else
-void *realloc_2(void *ptr, size_t size)
+void *realloc_2(void *ptr, size_t size
+#ifdef DEBUG_MALLOC_LINES
+, char *filename, int lineno
+#endif
+)
 {
 void *ret;
 
@@ -207,14 +238,22 @@ if(ret)
 	}
 	else
 	{
-	fprintf(stderr, "FATAL ERROR : Out of memory, sorry.\n");
+#ifdef DEBUG_MALLOC_LINES
+        fprintf(stderr, "FATAL ERROR: realloc_2() Out of memory, sorry. ['%s', %d]\n", filename, lineno);
+#else
+	fprintf(stderr, "FATAL ERROR : realloc_2() Out of memory, sorry.\n");
+#endif
 	exit(1);
 	}
 }
 #endif
 
 #ifdef _WAVE_HAVE_JUDY
-void *calloc_2_into_context(struct Global *g, size_t nmemb, size_t size)
+void *calloc_2_into_context(struct Global *g, size_t nmemb, size_t size
+#ifdef DEBUG_MALLOC_LINES
+, char *filename, int lineno
+#endif
+)
 {
 void *ret;
 
@@ -230,12 +269,20 @@ if(ret)
 	}
 	else
 	{
-	fprintf(stderr, "FATAL ERROR: Out of memory, sorry.\n");
+#ifdef DEBUG_MALLOC_LINES
+	fprintf(stderr, "FATAL ERROR: calloc_2() Out of memory, sorry. ['%s', %d]\n", filename, lineno);
+#else
+	fprintf(stderr, "FATAL ERROR: calloc_2() Out of memory, sorry.\n");
+#endif
 	exit(1);
 	}
 }
 #else
-void *calloc_2_into_context(struct Global *g, size_t nmemb, size_t size)
+void *calloc_2_into_context(struct Global *g, size_t nmemb, size_t size
+#ifdef DEBUG_MALLOC_LINES
+, char *filename, int lineno
+#endif
+)
 {
 void *ret;
 
@@ -257,20 +304,36 @@ if(ret)
 	}
 	else
 	{
-	fprintf(stderr, "FATAL ERROR: Out of memory, sorry.\n");
+#ifdef DEBUG_MALLOC_LINES
+        fprintf(stderr, "FATAL ERROR: calloc_2() Out of memory, sorry. ['%s', %d]\n", filename, lineno);
+#else
+	fprintf(stderr, "FATAL ERROR: calloc_2() Out of memory, sorry.\n");
+#endif
 	exit(1);
 	}
 }
 #endif
 
-void *calloc_2(size_t nmemb, size_t size)
+void *calloc_2(size_t nmemb, size_t size
+#ifdef DEBUG_MALLOC_LINES
+, char *filename, int lineno
+#endif
+)
 {
-return(calloc_2_into_context(GLOBALS, nmemb, size));
+return(calloc_2_into_context(GLOBALS, nmemb, size
+#ifdef DEBUG_MALLOC_LINES
+, filename, lineno
+#endif
+));
 }
 
 
 #ifdef _WAVE_HAVE_JUDY
-void free_2(void *ptr)
+void free_2(void *ptr
+#ifdef DEBUG_MALLOC_LINES
+, char *filename, int lineno
+#endif
+)
 {
 if(ptr)
 	{
@@ -284,16 +347,28 @@ if(ptr)
 		}
 		else
 		{
+#ifdef DEBUG_MALLOC_LINES
+		printf("JUDYMEM | free to non-malloc'd address %p blocked ['%s', %d]\n", ptr, filename, lineno);
+#else
 		printf("JUDYMEM | free to non-malloc'd address %p blocked\n", ptr);
+#endif
 		}
 	}
 	else
 	{
+#ifdef DEBUG_MALLOC_LINES
+        fprintf(stderr, "WARNING: Attempt to free NULL pointer caught. ['%s', %d]\n", filename, lineno);
+#else
 	fprintf(stderr, "WARNING: Attempt to free NULL pointer caught.\n");
+#endif
 	}
 }
 #else
-void free_2(void *ptr)
+void free_2(void *ptr
+#ifdef DEBUG_MALLOC_LINES
+, char *filename, int lineno
+#endif
+)
 {
 if(ptr)
 	{
@@ -321,11 +396,21 @@ if(ptr)
 	}
 	else
 	{
+#ifdef DEBUG_MALLOC_LINES
+        fprintf(stderr, "WARNING: Attempt to free NULL pointer caught. ['%s', %d]\n", filename, lineno);
+#else
 	fprintf(stderr, "WARNING: Attempt to free NULL pointer caught.\n");
+#endif
 	}
 }
 #endif
 
+
+#ifdef DEBUG_MALLOC_LINES
+#define malloc_2(x) malloc_2((x),__FILE__,__LINE__)
+#endif
+
+
 char *strdup_2(const char *s)
 {
 char *s2 = NULL;
@@ -365,6 +450,7 @@ TimeType atoi_64(const char *str)
 {
 TimeType val=0;
 unsigned char ch, nflag=0;
+int consumed = 0;
 
 GLOBALS->atoi_cont_ptr=NULL;
 
@@ -396,14 +482,16 @@ while((ch=*(str++)))
 	if((ch>='0')&&(ch<='9'))
 		{
 		val=(val*10+(ch&15));
+		consumed = 1;
 		}
 	else
 	if((ch=='-')&&(val==0)&&(!nflag))
 		{
 		nflag=1;
+		consumed = 1;
 		}
 	else
-	if(val)
+	if(consumed)
 		{
 		GLOBALS->atoi_cont_ptr=str-1;
 		break;
@@ -488,8 +576,17 @@ return(tmpspace);
 }
 
 /*
- * $Id: debug.c,v 1.14 2010/05/01 19:20:56 gtkwave Exp $
+ * $Id: debug.c,v 1.17 2010/09/16 05:05:16 gtkwave Exp $
  * $Log: debug.c,v $
+ * Revision 1.17  2010/09/16 05:05:16  gtkwave
+ * dummy up sparse vs regular array handling
+ *
+ * Revision 1.16  2010/09/16 04:08:55  gtkwave
+ * add back in memory debugging printfs and defines
+ *
+ * Revision 1.15  2010/08/03 17:36:51  gtkwave
+ * fixed atoi_64 parsing on zero values
+ *
  * Revision 1.14  2010/05/01 19:20:56  gtkwave
  * cppcheck warnings fixes
  *
