@@ -314,7 +314,7 @@ while(!feof(f))
 			for(;;)
 				{
 				if((*src == '\n') || (*src == '\r')) break;
-				if(isspace(*src))
+				if(isspace((int)(unsigned char)*src))
 					{
 					if(pchar != ' ') { *(pnt++) = pchar = ' '; }
 					src++;
@@ -501,8 +501,11 @@ return(0);
 }
 
 /*
- * $Id: evcd2vcd.c,v 1.3 2010/04/27 23:10:56 gtkwave Exp $
+ * $Id: evcd2vcd.c,v 1.4 2010/10/02 18:58:55 gtkwave Exp $
  * $Log: evcd2vcd.c,v $
+ * Revision 1.4  2010/10/02 18:58:55  gtkwave
+ * ctype.h compiler warning fixes (char vs int)
+ *
  * Revision 1.3  2010/04/27 23:10:56  gtkwave
  * made inttype.h inclusion conditional
  *
